@@ -198,15 +198,19 @@ class HBaseClient(metaclass=Singleton):
                     except Exception as e:
                         print(e)
                         continue
-                hp = r.row
-                dict_data['rowkey'] = hp.decode()
+                start_row = r.row.decode()
+                dict_data['rowkey'] = start_row
                 yield dict_data
             try:
+                tscan = TScan(startRow=str(start_row).encode() if start_row else None)
+                scan_id = self.client.openScanner(str(hbase_table).encode(), tscan)
                 row_list = self.client.getScannerRows(scan_id, 1000)
             except Exception as e:
                 self.close()
                 print(e)
                 self.reconnect()
+                tscan = TScan(startRow=str(start_row).encode() if start_row else None)
+                scan_id = self.client.openScanner(str(hbase_table).encode(), tscan)
                 row_list = self.client.getScannerRows(scan_id, 1000)
         else:
             self.close()
